commit-gnue
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

gnue/geas/tools Makefile.am parse_load_sql.py


From: Reinhard Mueller
Subject: gnue/geas/tools Makefile.am parse_load_sql.py
Date: Fri, 20 Jul 2001 03:33:02 -0700

CVSROOT:        /cvsroot/gnue
Module name:    gnue
Changes by:     Reinhard Mueller <address@hidden>       01/07/20 03:33:02

Modified files:
        geas/tools     : Makefile.am parse_load_sql.py 

Log message:
        Replaced gen_uuid by standard uuidgen which comes with libuuid

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/gnue/gnue/geas/tools/Makefile.am.diff?tr1=1.7&tr2=1.8&r1=text&r2=text
http://savannah.gnu.org/cgi-bin/viewcvs/gnue/gnue/geas/tools/parse_load_sql.py.diff?tr1=1.6&tr2=1.7&r1=text&r2=text

Patches:
Index: gnue/geas/tools/Makefile.am
diff -u gnue/geas/tools/Makefile.am:1.7 gnue/geas/tools/Makefile.am:1.8
--- gnue/geas/tools/Makefile.am:1.7     Sat Jul  7 09:25:40 2001
+++ gnue/geas/tools/Makefile.am Fri Jul 20 03:33:02 2001
@@ -1,13 +1,9 @@
-## $Id: Makefile.am,v 1.7 2001/07/07 16:25:40 ntiffin Exp $
+## $Id: Makefile.am,v 1.8 2001/07/20 10:33:02 reinhard Exp $
 
-bin_PROGRAMS = gcdverifier gen_uuid
+bin_PROGRAMS = gcdverifier
 
-INCLUDES = $(GLIB_CFLAGS) -I/usr/local/include/uuid
-LDADD = $(GLIB_LIBS) ../lib/classdefs/libclassdefs.a -luuid
+INCLUDES = $(GLIB_CFLAGS) -I$(top_srcdir)/lib/classdefs
 
-gcdverifier_SOURCES = gcdverifier.c
-gcdverifier_INCLUDES = $(GLIB_CFLAGS) -I$(top_srcdir)/lib/classdefs
-
+LDADD = $(GLIB_LIBS) ../lib/classdefs/libclassdefs.a
 
-gen_uuid_SOURCES = gen_uuid.c
-gen_uuid_INCLUDES = $(GLIB_CFLAGS) -I/usr/local/include/uuid
+gcdverifier_SOURCES = gcdverifier.c
Index: gnue/geas/tools/parse_load_sql.py
diff -u gnue/geas/tools/parse_load_sql.py:1.6 
gnue/geas/tools/parse_load_sql.py:1.7
--- gnue/geas/tools/parse_load_sql.py:1.6       Sat Jul  7 09:48:08 2001
+++ gnue/geas/tools/parse_load_sql.py   Fri Jul 20 03:33:02 2001
@@ -26,9 +26,9 @@
 #
 # This program originally written by Neil Tiffin (address@hidden).
 #
-# $Id: parse_load_sql.py,v 1.6 2001/07/07 16:48:08 ntiffin Exp $
+# $Id: parse_load_sql.py,v 1.7 2001/07/20 10:33:02 reinhard Exp $
 #
 # to use this program you will need the program "gen_uuid"
 # compliled and located in the same dir as this file, then
 # type "./parse_load_sql.py [dir_name]"
 #    where dir_name = the top level dir to start search for
@@ -73,15 +73,19 @@
 do_all = " "
 
 def get_uuid():
-       global my_uuids
-       if (len(my_uuids) < 2):
-               f = os.popen("./gen_uuid -n 25", "r")
-               uuids = f.readlines()
-               for uuid in uuids:
-                       if len(uuid) and (uuid[-1] == "\n"):
-                               my_uuids.append(uuid[:-1])
-               f.close()
-       return my_uuids.pop()
+#      global my_uuids
+#      if (len(my_uuids) < 2):
+#              f = os.popen("./gen_uuid -n 25", "r")
+#              uuids = f.readlines()
+#              for uuid in uuids:
+#                      if len(uuid) and (uuid[-1] == "\n"):
+#                              my_uuids.append(uuid[:-1])
+#              f.close()
+#      return my_uuids.pop()
+       f = os.popen("uuidgen", "r")
+       uuid = f.readline()
+       f.close()
+       return uuid
 
 # temp = get_uuid()
 # print my_uuids
@@ -26,9 +26,9 @@
 #
-# to use this program you will need the program "gen_uuid"
+# to use this program you will need the program "uuidgen"
 # compliled and located in the same dir as this file, then
 # type "./parse_load_sql.py [dir_name]"



reply via email to

[Prev in Thread] Current Thread [Next in Thread]